package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jun 25, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ClientConfig struct {
DefaultLanguage string `json:"defaultLanguage"`
DefaultTheme string `json:"defaultTheme"`
RefreshMS int64 `json:"refreshMS"`
APIPath string `json:"apiPath"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.